@@ -31,6 +31,18 @@ class DetectVideoIPCObjectRequest(RpcRequest):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
 
+	def get_StartTimestamp(self):
+		return self.get_body_params().get('StartTimestamp')
+
+	def set_StartTimestamp(self,StartTimestamp):
+		self.add_body_params('StartTimestamp', StartTimestamp)
+
+	def get_CallbackOnlyHasObject(self):
+		return self.get_body_params().get('CallbackOnlyHasObject')
+
+	def set_CallbackOnlyHasObject(self,CallbackOnlyHasObject):
+		self.add_body_params('CallbackOnlyHasObject', CallbackOnlyHasObject)
+
 	def get_VideoURL(self):
 		return self.get_body_params().get('VideoURL')
 
